==> bunzbar-0.53.tar.gz: bunzbar-0.53/README.md <==
# Bunzbar

## System requirements
+ Linux system with X.Org display server

## How to get it

+ If you use Archlinux you can get the bunzbar by installing the PKGBUILD file.
+ For other distributions see Manual installation.

## Manual installation

### Get the Python module installed

First of all you need to install the bunzbar python module.
After installing python and pip, use one of the following options to install it.

+ pip
```bash
pip install bunzbar
```
+ from source
```bash
git clone https://gitlab.com/02742/bunzbar.git
cd bunzbar
pip install build twine
make build
pip install dist/*.whl
```
+ from source (curl)

### Install service file and enable it
```
curl -s https://cdn.statically.io/gl/02742/bunzbar/main/makefile | make install_service -f -
```

### Post installation

#### Make the command accessable 

A few options to acceave this

+ Add `~/.local/bin` to your `$PATH` (non persistant)
```bash
export PATH=~/.local/bin:$PATH
```
+ Add it to your `$PATH` using your `.bashrc` file
```bash
echo "export PATH=~/.local/bin:$PATH" >> .bashrc
```
+ Create a link
```bash
ln -s ~/.local/bin/bunzbar /usr/bin/bunzbar
```
+ Get Arch

#### Configuration
You can toggle an info in the bar with the following command:
```bash
bunzbar -it <toogle_name>
```
To get a list of these names simply execute:
```bash
bunzbar -il
```
If you want to change an option in the config file you can do that using:
```bash
bunzbar -cs <config_option> <value>
```
Again you can list the available config options using:
```bash
bunzbar -cl
```

#### Start bunzbar in daemon mode
For bunzbar to continously update the x root main window name it needs to be started in daemon mode
```bash
bunzbar -d
```

## Links

+ [gitlab](https://gitlab.com/02742/bunzbar/)
+ [pypi](https://pypi.org/project/bunzbar/)

==> bunzbar-0.58.tar.gz: bunzbar-0.58/README.md <==
# Bunzbar

## System requirements
+ Linux system with X.Org display server

## Installation

### Install Python package

First of all you need to install the bunzbar python module.
After installing python and pip, use one of the following options to install it.

+ pip
```bash
pip install bunzbar
```
+ from source
```bash
pip install build twine
git clone https://gitlab.com/02742/bunzbar.git
cd bunzbar && python3 -m build
pip install dist/*.whl --force-reinstall
```
```bash
curl -s https://cdn.statically.io/gl/02742/bunzbar/main/makefile | make build_git -f -
```

### Add `~/.local/bin` to your `$PATH`
```bash
export PATH=~/.local/bin:${PATH}
echo "export PATH=~/.local/bin:${PATH}" >> ~/.bashrc
```
```bash
curl -s https://cdn.statically.io/gl/02742/bunzbar/main/makefile | make add_to_path -f -
```

### [systemd] Install service file and enable it
```bash
curl -s https://cdn.statically.io/gl/02742/bunzbar/main/makefile | make install_service -f -
```

### [non systemd] Start bunzbar in daemon mode
```bash
bunzbar -d
```

## Configuration
You can toggle an info in the bar with the following command:
```bash
bunzbar -it <toogle_name>
```
To get a list of these names simply execute:
```bash
bunzbar -il
```
If you want to change an option in the config file you can do that using:
```bash
bunzbar -cs <config_option> <value>
```
Again you can list the available config options using:
```bash
bunzbar -cl
```


## Links

+ [gitlab](https://gitlab.com/02742/bunzbar/)
+ [pypi](https://pypi.org/project/bunzbar/)
